# anonfile-upload-script
An upload script for anonfile.com made in python. Supports multiple files.

![GitHub Contributors](https://img.shields.io/github/contributors/jakbin/anonfile-upload)

![GitHub commit activity](https://img.shields.io/github/commit-activity/m/jakbin/anonfile-upload)

![GitHub last commit](https://img.shields.io/github/last-commit/jakbin/anonfile-upload)

![Python 3.6](https://img.shields.io/badge/python-3.6-yellow.svg)

![Pypi 20.3](https://img.shields.io/badge/pypi-20.3-orange.svg)


## Installation

```bash
pip3 install anonupload
```

## Usage

```bash
anon {path-to-file 1} {path-to-file 2}...
```
## You can change file name before upload on anonfile server
